# sparrow_tool
[![image](https://img.shields.io/badge/Pypi-0.3.5-green.svg)](https://pypi.org/project/sparrow_tool)
[![image](https://img.shields.io/badge/python-3.6+-blue.svg)](https://www.python.org/)
[![image](https://img.shields.io/badge/license-GNU_GPL--v3-blue.svg)](LICENSE)
[![image](https://img.shields.io/badge/author-kunyuan-orange.svg?style=flat-square&logo=appveyor)](https://github.com/beidongjiedeguang)

## Requirements
```python
pyyaml
numpy
colour
pendulum
twine
cn2an
colorlog
concurrent-log-handler
Deprecated
GitPython
```

-------------------------
## Install
```bash
pip install sparrow-tool
```

## Usage
TODO